@@ -677,6 +677,8 @@ class MainWindowController(QObject):
             self._networkControllerFailed(kvargs['error'])
         elif 'mindmap' in kvargs:
             self._loadMindMap(kvargs['mindmap'])
+        elif 'undostack' in kvargs:
+            self.__undoStack = kvargs['undostack']
 
     def _networkControllerFailed(self, reason):
         '''
@@ -709,7 +711,7 @@ class MainWindowController(QObject):
         def _accept():
             settings = dialog.attributes()
             self.__networkController.startHiveMindService(settings['userJid'] + '/hivemind',
-                    settings['password'], self.__mindMapScene.mindMap)
+                    settings['password'], self.__mindMapScene.mindMap, self.__undoStack)
         dialog = gui_factory.createXMPPCredentialsDialog(False, self.__mainWindow)
         dialog.connect(SIGNAL('accepted()'), _accept)
         dialog.exec_()
