@@ -557,9 +557,11 @@ def _deserializeAddNodeCommand(commandElement, mindMap):
     parent = mindMap.getNodeById(parentElement.get('id'))
     nodeElement = commandElement[1]
     child = _parseNode(nodeElement, parent)
-    index = int(parentElement.get('childIndex'))
     if child.left is None: child.setAttributes(left = parent.left)
-    return AddNodeCommand(parent, child, index)
+    index = parentElement.get('childIndex')
+    if index is not None:
+        return AddNodeCommand(parent, child, int(index))
+    return AddNodeCommand(parent, child)
 
 def _deserializeMoveNodeCommand(commandElement, mindMap):
     '''
